This part of the project documentation is a 
reference for the technical implementation of the `VoDEx` project code. 

# vodex.loaders module
::: src.vodex.loaders
    options:
      members:
        - None
      show_root_heading: false
      show_source: false

# vodex.core module
::: src.vodex.core
    options:
      members:
        - None
      show_root_heading: false
      show_source: false

# vodex.dbmethods module
::: src.vodex.dbmethods
    options:
      members:
        - None
      show_root_heading: false
      show_source: false